@@ -1,5 +1,5 @@
 /*
-                  Endeavour Browser Contents List
+		  Endeavour Browser Contents List
  */
 
 #ifndef BROWSERCONTENTS_H
@@ -11,42 +11,42 @@
 
 
 extern gint EDVBrowserContentsFindRowByPath(
-        edv_browser_struct *browser, const gchar *path
+	edv_browser_struct *browser, const gchar *path
 );
 
 extern void EDVBrowserContentsResetRows(edv_browser_struct *browser);
 extern void EDVBrowserContentsDoUpdate(
 	edv_browser_struct *browser, const gchar *path,
-	gbool update_status_bar
+	gboolean update_status_bar
 );
 
 extern void EDVBrowserContentsDoOpenObject(
-        edv_browser_struct *browser, gint row, gint column, guint state
+	edv_browser_struct *browser, gint row, gint column, guint state
 );
 extern void EDVBrowserContentsDoOpenWithObject(
-        edv_browser_struct *browser, gint row, gint column
+	edv_browser_struct *browser, gint row, gint column
 );
 
 extern void EDVBrowserContentsDoFPromptRename(
-        edv_browser_struct *browser, gint row, gint column
+	edv_browser_struct *browser, gint row, gint column
 );
 
 extern void EDVBrowserContentsObjectAddedNotify(
-        edv_browser_struct *browser, const gchar *path,
-        const struct stat *lstat_buf
+	edv_browser_struct *browser, const gchar *path,
+	const struct stat *lstat_buf
 );
 extern void EDVBrowserContentsObjectModifiedNotify(
-        edv_browser_struct *browser, const gchar *path,
-        const gchar *new_path,
-        const struct stat *lstat_buf
+	edv_browser_struct *browser, const gchar *path,
+	const gchar *new_path,
+	const struct stat *lstat_buf
 );
 extern void EDVBrowserContentsObjectRemovedNotify(
-        edv_browser_struct *browser, const gchar *path
+	edv_browser_struct *browser, const gchar *path
 );
 
 extern void EDVBrowserContentsMountNotify(
-        edv_browser_struct *browser, edv_device_struct *dev_ptr,
-        gbool is_mounted
+	edv_browser_struct *browser, edv_device_struct *dev_ptr,
+	gboolean is_mounted
 );
 
 
