@@ -1,5 +1,5 @@
 /*
-                   Endeavour Customize window creation
+	               Endeavour Customize Window
  */
 
 #ifndef EDVCUSTOMIZE_H
@@ -8,10 +8,11 @@
 #include <gtk/gtk.h>
 #include "optwin.h"
 
+
 extern void EDVCustomizeWindowSelectTab(
-        edv_optwin_struct *optwin, const gchar *tab_name
+	optwin_struct *optwin, const gchar *tab_name
 );
-extern edv_optwin_struct *EDVCreateCustomizeWindow(
+extern optwin_struct *EDVCreateCustomizeWindow(
 	gpointer core_ptr
 );
 
