@@ -1,5 +1,5 @@
 /*
-                       Endeavour Process Execution
+		       Endeavour Process Execution
 
 	To run a program specified by the MIME Type of a given disk object
 	path or name.
@@ -16,16 +16,16 @@
 
 extern gint EDVOpenObjectPath(
 	edv_core_struct *core_ptr, const gchar *path,
-        const gchar *command_name,
-	GtkWidget *toplevel, gbool verbose,
+	const gchar *command_name,
+	GtkWidget *toplevel, gboolean verbose,
 	gchar **stdout_path_rtn, gchar **stderr_path_rtn
 );
 
 extern gint EDVOpenWithObjectPath(
-        edv_core_struct *core_ptr, const gchar *path,
-        const gchar *command_name,
-        GtkWidget *toplevel, gbool verbose,
-        gchar **stdout_path_rtn, gchar **stderr_path_rtn
+	edv_core_struct *core_ptr, const gchar *path,
+	const gchar *command_name,
+	GtkWidget *toplevel, gboolean verbose,
+	gchar **stdout_path_rtn, gchar **stderr_path_rtn
 );
 
 
