@@ -1,17 +1,14 @@
 /*
- *	Open object
- *
- *	Instructs the Endeavour program to open an object by checking
- *	the object's extension and matching it through its MIME Types
- *	list.  If a method to open the object is found, then that method
- *	will be used to open the object.
+                               Open Objects
  */
 
 #ifndef EDVOPEN_H
 #define EDVOPEN_H
 
+#include <glib.h>
 #include "edvcontext.h"
 
+
 /*
  *      Instructs the Endeavour program to open an object by checking
  *      the object's extension and matching it through its MIME Types
@@ -27,8 +24,9 @@
  *	set so it is recommended that command_name be left NULL.
  */
 extern void EDVOpen(
-        edv_context_struct *ctx,
-        const gchar *path, const gchar *command_name
+	edv_context_struct *ctx,
+	const gchar *path, const gchar *command_name
 );
 
+
 #endif	/* EDVOPEN_H */
